eprllib.Env.MultiAgent.EnvUtils — eprllib: use EnergyPlus as an environment for DRL control

Skip to main content
`Ctrl`+`K`

# eprllib.Env.MultiAgent.EnvUtils

## Environment Utilities

This module contain the methods used in the environment process.

Functions

`EP_API_add_path`([version, path]) | This method add the EnergyPlus Python API to the system path.
`actuators`(env_config, _agent_ids) | The EnergyPlus actuators are defined in the environment configuration.
`actuators_to_agents`(agent_config) | Take the ep_actuator dict and transform it to the agent, thermal zone, and actuator type dict.
`continuous_action_space`() | This method construct the action space of the environment.
`discrete_action_space`() | This method construct the action space of the environment.
`environment_variables`(env_config) | The EnergyPlus outdoor environment variables are defined in the environment configuration.
`meters`(env_config) | The EnergyPlus meters are defined in the environment configuration.
`object_variables`(env_config, _thermal_zone_ids) | The EnergyPlus object variables are defined in the environment configuration.
`obs_space`(env_config, _thermal_none_ids) | This method construct the observation space of the environment.
`thermal_zone_variables`(env_config, ...) | The EnergyPlus thermal zone variables are defined in the environment configuration.